package cn.hzxy.springbootusejpa.service;

import cn.hzxy.springbootusejpa.entity.NewTeacher;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;

import java.awt.print.Pageable;
import java.util.Collection;
import java.util.List;

public interface NewTeacherService {
    NewTeacher findById(String id);
    List<NewTeacher> findAll();
    NewTeacher sava(NewTeacher newTeacher);
    void delete(String id);

    Page<NewTeacher> findAll(PageRequest pageRequest);
    List<NewTeacher> findByName(String name);
    List<NewTeacher> findByNameLike(String name);
    List<NewTeacher> findByIdIn(Collection<String> ids);

}
